(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      6642,        202]
NotebookOptionsPosition[      5868,        171]
NotebookOutlinePosition[      6227,        187]
CellTagsIndexPosition[      6184,        184]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook shows you how to calculate the Inverse Fourier and Fourier \
Transform of the solution to the diffusion equation.\[LineSeparator]\
\[LineSeparator]Note, as discussed in class, there are many possible \
equivalent, but different implementations of the Fourier transform in science \
and the default used in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a preferred version by Mathematicians, because it is fully symmetric, \
but is not the form we have defined (see \
http://reference.wolfram.com/language/ref/FourierParameters.html for details \
if you are interested). Thus inside the transforms we have to include the \
expression FourierParameters\[Rule]{1,1}, which enables ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to implement the Fourier transform as we have defined it.\n\nFirst let us \
write the basic solution to the diffusion equation in Fourier space, which we \
found by solving the ODE in Fourier space. We consider the delta initial \
condition as described in the notes.\n"
}], "Text",
 CellChangeTimes->{{3.6286887295047483`*^9, 3.628688978253811*^9}, 
   3.628689008325129*^9, {3.630173714586692*^9, 3.6301737150650873`*^9}}],

Cell[BoxData[
 RowBox[{"Ck", ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "d"}], "*", 
    RowBox[{"k", "^", "2"}], "*", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.628688929973032*^9, 3.628688946451589*^9}, {
   3.6286979120288754`*^9, 3.628697926584366*^9}, 3.628697986101796*^9}],

Cell["\<\

We now have to invert this to real space using the Inverse Fourier Transform \
command\
\>", "Text",
 CellChangeTimes->{{3.628688990942974*^9, 3.62868901086287*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseFourierTransform", "[", 
  RowBox[{"Ck", ",", "k", ",", "x", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.628689140298151*^9, 3.6286891405776978`*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["x", "2"], 
     RowBox[{"4", " ", "d", " ", "t"}]]}]], 
  RowBox[{"2", " ", 
   SqrtBox["\[Pi]"], " ", 
   SqrtBox[
    RowBox[{"d", " ", "t"}]]}]]], "Output",
 CellChangeTimes->{3.6286890250521107`*^9, 3.628689151143775*^9}]
}, Open  ]],

Cell["\<\
This is exactly the solution that we obtained in class and know to be the \
solution to the diffusion equation. Again, note that for the FT to be \
consistent with our definition from class we need to include the last part \
where we set the Fourier parameters to 1,1\[LineSeparator]
Now just for completeness so that you can see how we perform the forward \
transform we will transform the solution in real space into Fourier space\
\>", "Text",
 CellChangeTimes->{{3.628689030412521*^9, 3.6286891177378893`*^9}}],

Cell[BoxData[
 RowBox[{"Cx", ":=", 
  FractionBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["x", "2"], 
      RowBox[{"4", " ", "d", " ", "t"}]]}]], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", "t"}]]}]]}]], "Input",
 CellChangeTimes->{{3.6286891262263603`*^9, 3.628689129605329*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourierTransform", "[", 
  RowBox[{"Cx", ",", "x", ",", "k", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.628689164876012*^9, 3.62868917339647*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "d"}], " ", 
    SuperscriptBox["k", "2"], " ", "t"}]], " ", 
  SqrtBox[
   FractionBox["1", 
    RowBox[{"d", " ", "t"}]]], " ", 
  SqrtBox[
   RowBox[{"d", " ", "t"}]]}]], "Output",
 CellChangeTimes->{{3.628689167719996*^9, 3.628689174220364*^9}}]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is struggling here to cancel the dt terms because it does not know is they \
are real, imaginary or whatever. This can be resolved by letting it know that \
both d and t must be greater than zero. By the way we use d instead of D, \
only because D is a protected symbol in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that represents a differentiation operator.\n\nBy using Simplify and \
putting the conditions that d>0 and t>0 at the end we can simplify the \
expression so that it looks exactly like what we are used to"
}], "Text",
 CellChangeTimes->{{3.628689184110512*^9, 3.6286892565675993`*^9}, {
  3.628689287903392*^9, 3.628689317982574*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"FourierTransform", "[", 
    RowBox[{"Cx", ",", "x", ",", "k", ",", 
     RowBox[{"FourierParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.628689259830552*^9, 3.628689279456451*^9}}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"-", "d"}], " ", 
   SuperscriptBox["k", "2"], " ", "t"}]]], "Output",
 CellChangeTimes->{3.62868928005816*^9}]
}, Open  ]]
},
WindowSize->{808, 552},
WindowMargins->{{838, Automatic}, {Automatic, 326}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1201, 21, 258, "Text"],
Cell[1762, 43, 300, 7, 28, "Input"],
Cell[2065, 52, 176, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[2266, 61, 285, 6, 28, "Input"],
Cell[2554, 69, 345, 11, 67, "Output"]
}, Open  ]],
Cell[2914, 83, 524, 8, 125, "Text"],
Cell[3441, 93, 380, 12, 69, "Input"],
Cell[CellGroupData[{
Cell[3846, 109, 275, 6, 28, "Input"],
Cell[4124, 117, 339, 11, 56, "Output"]
}, Open  ]],
Cell[4478, 131, 745, 15, 144, "Text"],
Cell[CellGroupData[{
Cell[5248, 150, 418, 11, 28, "Input"],
Cell[5669, 163, 183, 5, 36, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
