(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      5570,        175]
NotebookOptionsPosition[      4803,        144]
NotebookOutlinePosition[      5162,        160]
CellTagsIndexPosition[      5119,        157]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook shows you how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve the ordinary differential equation that arises when you convert \
the diffusion equation into Fourier Space\n\nThe equation in Fourier space is \
given by (note ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not like it when I use C(t) with little t, because it is a protected \
symbol in the language)"
}], "Text",
 CellChangeTimes->{{3.630171633663405*^9, 3.630171670338069*^9}, {
  3.630172059912437*^9, 3.630172087504306*^9}, {3.630172531622046*^9, 
  3.630172533590023*^9}, {3.6301726011106577`*^9, 3.630172601237732*^9}}],

Cell[BoxData[
 RowBox[{"Eq", ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Chat", "[", "T", "]"}], ",", "T"}], "]"}], "==", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"k", "^", "2"}]}], "*", 
    RowBox[{"Chat", "[", "T", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.630171673176354*^9, 3.630171721490848*^9}, {
  3.630171822099182*^9, 3.630171850914648*^9}, {3.6301718972664127`*^9, 
  3.630171911337523*^9}, {3.630171951003312*^9, 3.630171963177346*^9}, {
  3.6301720310587063`*^9, 3.630172052049699*^9}, {3.6301721518568363`*^9, 
  3.630172152192829*^9}, {3.630172190105077*^9, 3.630172193231977*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Eq"], "Input",
 CellChangeTimes->{{3.63017215477496*^9, 3.630172154928051*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["Chat", "\[Prime]",
    MultilineFunction->None], "[", "T", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["k", "2"]}], " ", 
   RowBox[{"Chat", "[", "T", "]"}]}]}]], "Output",
 CellChangeTimes->{3.6301721553553963`*^9, 3.630172197226796*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630171723345173*^9, 3.630171728338107*^9}, 
   3.630172095977714*^9}],

Cell["\<\
We can now solve the differential equation generally using the function DSolve\
\>", "Text",
 CellChangeTimes->{{3.630172546556404*^9, 3.630172569517901*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.63017209787224*^9, 3.630172097876514*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{"Eq", ",", 
   RowBox[{"Chat", "[", "T", "]"}], ",", "T"}], "]"}]], "Input",
 CellChangeTimes->{{3.630171689006865*^9, 3.63017171107479*^9}, {
  3.630171752178185*^9, 3.6301717601220303`*^9}, {3.63017210400937*^9, 
  3.630172129448476*^9}, {3.630172203343985*^9, 3.6301722035362797`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Chat", "[", "T", "]"}], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["k", "2"]}], " ", "T"}]], " ", 
     RowBox[{"C", "[", "1", "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.630171692861071*^9, 3.630171706657941*^9}, 
   3.6301717604964457`*^9, {3.630172130034923*^9, 3.630172159221291*^9}, {
   3.630172199127206*^9, 3.630172203818676*^9}, 3.630172493594659*^9}]
}, Open  ]],

Cell[TextData[{
 "Note that this solution is Chat(t)=C_1 exp(-k^2 *t)\n\nwhere C_1 is a \
constant of integration that you need an initial condition to satisfy\n\nIn \
our case Chat(t=0)=1 => C_1 =1\n\n\nAlternatively, but not always you can ask \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve with an initial condition as "
}], "Text",
 CellChangeTimes->{{3.630172176416429*^9, 3.630172285079176*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Eq", ",", 
     RowBox[{
      RowBox[{"Chat", "[", "0", "]"}], "==", "1"}]}], "}"}], ",", 
   RowBox[{"Chat", "[", "T", "]"}], ",", "T"}], "]"}]], "Input",
 CellChangeTimes->{{3.6301723107523613`*^9, 3.6301723595118113`*^9}, {
  3.6301724845204163`*^9, 3.6301724866866426`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Chat", "[", "T", "]"}], "\[Rule]", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["k", "2"]}], " ", "T"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.630172324015876*^9, 3.630172364035676*^9}, 
   3.6301724452265263`*^9, {3.6301724871968307`*^9, 3.6301724984565973`*^9}}]
}, Open  ]]
},
WindowSize->{808, 911},
WindowMargins->{{357, Automatic}, {Automatic, 145}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 657, 14, 106, "Text"],
Cell[1218, 36, 626, 14, 28, "Input"],
Cell[CellGroupData[{
Cell[1869, 54, 93, 1, 28, "Input"],
Cell[1965, 57, 315, 9, 32, "Output"]
}, Open  ]],
Cell[2295, 69, 118, 2, 28, "Input"],
Cell[2416, 73, 168, 3, 30, "Text"],
Cell[2587, 78, 91, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[2703, 83, 337, 6, 28, "Input"],
Cell[3043, 91, 525, 13, 42, "Output"]
}, Open  ]],
Cell[3583, 107, 420, 9, 163, "Text"],
Cell[CellGroupData[{
Cell[4028, 120, 359, 9, 28, "Input"],
Cell[4390, 131, 397, 10, 42, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
